@@ -114,7 +114,7 @@ class SkeletonVisualizer:
         self.plot: SkeletonPlot = None
         self.size_scalar: float = size_scalar
         self.skeletons: List[DrawableSkeleton] = []
-        self.joint_name_visibility_button = widgets.Button(description="Hide joint names")
+        self.checkbox = widgets.Checkbox()
 
     def visualize(self, skeletons: np.ndarray, colors: List[Color] = None):
         self.__assert_visualization_arguments(skeletons, colors)
@@ -122,9 +122,9 @@ class SkeletonVisualizer:
         if colors is None:
             colors = ['default' for i in range(number_of_skeletons)]
         self.plot = self.__create_skeleton_plot(skeletons, colors)
-        self.joint_name_visibility_button.on_click(callback=self.__hide_skeleton_joint_names, remove=True)
-        display(objs=self.joint_name_visibility_button)
+        self.__link_joint_name_visibility_with_checkbox()
         self.plot.display()
+        display(self.checkbox)
 
     def __assert_visualization_arguments(self, skeletons: np.ndarray, colors: List[Color]):
         assert len(skeletons.shape) == 3, 'The \'skeletons\' parameter should be a 3 dimensional numpy array.'
@@ -154,17 +154,10 @@ class SkeletonVisualizer:
         max_values = [abs(skeleton).max() for skeleton in skeletons]
         return (min(max_values) / 50.0) * self.size_scalar
 
-    def __hide_skeleton_joint_names(self):
+    def __link_joint_name_visibility_with_checkbox(self):
         for skeleton in self.skeletons:
-            skeleton.hide_joint_names()
-        self.joint_name_visibility_button.description = "Show joint names"
-        self.joint_name_visibility_button.on_click(callback=self.__show_skeleton_joint_names(), remove=True)
-
-    def __show_skeleton_joint_names(self):
-        for skeleton in self.skeletons:
-            skeleton.show_joint_names()
-        self.joint_name_visibility_button.description = "Hide joint names"
-        self.joint_name_visibility_button.on_click(callback=self.__hide_skeleton_joint_names(), remove=True)
+            for joint_name in skeleton.joint_names:
+                widgets.jslink((joint_name, 'visible'), (self.checkbox, 'value'))
 
 
 class MuPoTSVisualizer(SkeletonVisualizer):
